Components › Pricing — Stisla

# Pricing

Price components are very important for SaaS projects or other projects.

Developer
$19
per month
1 user agent
Core features
1GB storage
2 Custom domain
Live Support
Subscribe
Small Team
$60
per month
5 user agent
Core features
10GB storage
10 Custom domain
24/7 Support
Subscribe
Enterprise
$499
per month
Unlimited user agent
Core features
8TB storage
Unlimited custom domain
Lifetime Support
Subscribe